@@ -14,7 +14,6 @@ Usage::
 from datetime import datetime
 from typing import Any, Dict, List, Type
 
-from boto3.botocore_stubs import ClientError as BotocoreClientError
 from botocore.client import ClientMeta
 
 from mypy_boto3_kinesisanalytics.type_defs import (
@@ -38,6 +37,14 @@ from mypy_boto3_kinesisanalytics.type_defs import (
 __all__ = ("KinesisAnalyticsClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
     ClientError: Type[BotocoreClientError]
     CodeValidationException: Type[BotocoreClientError]
